==> mishkal_hebrew-0.3.2.tar.gz: mishkal_hebrew-0.3.2/examples/phonemize.py <==
"""
Quick Nakdan https://nakdanlive.dicta.org.il
Pro Nakdan https://nakdanpro.dicta.org.il
Manual Nakdan https://www.yo-yoo.co.il/tools/niqqud
"""

from mishkal import phonemize

sentences = [
    # "הִיא אָמְרָה לִי",  # Hirik with Yod vowel
    # "מָה קוֹרֶה?",  # Vav with Holam vowel
    # "הוּא קֵרֵחַ",  # Het gnuva
    # "גִ'ירָפָה זַ'רְגּוֹן",  # Geresh
    # "שָׁלוֹם שׂוֹרֵר",  # Shin Sin
    # "לְבִיבָה יְלָדִים שְׁאֵלָה בְּהֵמָה זְעָקוֹת בְּרֹאשׁ גּוֹרְרִים מְצַפְצְפִים מִרְפְּאוֹתֵיהֶם",  # Shva na
    # "בְּרוֹשׁ סְבִיבָה בְּרָגִים שְׁפֵלָה בְּרֵכָה זְנָבוֹת גּוֹרְמִים הָלַכְתְּ וּבְרָכָה",  # Shva nax
    # "אַתָּה חַיָּב לִי 50 שֶׁקֶל וְהַסֵּמֶל הוּא ₪",  # numbers, symbols
    # "כל",  # dictionary
    # "ווֹלְטֶר",  # double vav start
    # "הֲווֹלְטֶר",  # double vav middle
    # "אֶלֶגַנְטִי",  # lookup
    # "כָּל",  # match to one without niqqud
    # "יִשְׂרָאֵל הוּקְמָה בִּשְׁנַת 1948",
    # "₪",
    # "מָחָר בְּשָׁעָה 22:00",  # time to word
    # "אוֹרוֹת ווֹלְטֶר ווֹלֶנְטַיְן אֻרְווֹת אוֹרְחִים אָרְבוּ הוֹוֶה וּוּבְּרִים וָו וִי וּוִיקְטוֹר",  # Vavs
    # "לְמַיִם אֱלֹהֵי",
    # "שְׁמַע אָח שֶׁלִּי, תִּרְאֶה. נִרְאֶה לִי שֶׁזֶּה עוֹבֵד!",
    # "גִ'ירָפָה",
    # "יִהְיֶה",
    # "בְּמָה",
    # "בְּיִשְׂרָאֵל.",
    # "אֲוִויר",
    # "לַכִּיווּן",
    # """קִיוּוּ""",
    # "אֻרְווֹת",
    # "וּוִיקְטוֹר",
    # "אֲוִויר",
    # "מְאוּוְרֶרֶת",
    # "טוֹוִים",
    # "מִגְוַון",
    # "הַקַּווְקָז",
    # "בְּסִיוֹוֹן",
    # "צוֹוַחַת",
    # "צוֹוְחִים",
    # "וּוֶנְדֶּר",
    # "וּוַעֲדַת",
    # "שָׁלוֹם",
    # "וּמֶה",
    "הַתְּרוּמָה",
    "English",
    "בַּרִיא וֵחַזַק1",
]


for sentence in sentences:
    phonemes = phonemize(sentence, preserve_punctuation=True)
    print(phonemes)

==> mishkal_hebrew-0.3.4.tar.gz: mishkal_hebrew-0.3.4/examples/phonemize.py <==
"""
Quick Nakdan https://nakdanlive.dicta.org.il
Pro Nakdan https://nakdanpro.dicta.org.il
Manual Nakdan https://www.yo-yoo.co.il/tools/niqqud
"""

from mishkal import phonemize

sentences = [
    # "הִיא אָמְרָה לִי",  # Hirik with Yod vowel
    # "מָה קוֹרֶה?",  # Vav with Holam vowel
    # "הוּא קֵרֵחַ",  # Het gnuva
    # "גִ'ירָפָה זַ'רְגּוֹן",  # Geresh
    # "שָׁלוֹם שׂוֹרֵר",  # Shin Sin
    # "לְבִיבָה יְלָדִים שְׁאֵלָה בְּהֵמָה זְעָקוֹת בְּרֹאשׁ גּוֹרְרִים מְצַפְצְפִים מִרְפְּאוֹתֵיהֶם",  # Shva na
    # "בְּרוֹשׁ סְבִיבָה בְּרָגִים שְׁפֵלָה בְּרֵכָה זְנָבוֹת גּוֹרְמִים הָלַכְתְּ וּבְרָכָה",  # Shva nax
    # "אַתָּה חַיָּב לִי 50 שֶׁקֶל וְהַסֵּמֶל הוּא ₪",  # numbers, symbols
    # "כל",  # dictionary
    # "ווֹלְטֶר",  # double vav start
    # "הֲווֹלְטֶר",  # double vav middle
    # "אֶלֶגַנְטִי",  # lookup
    # "כָּל",  # match to one without niqqud
    # "יִשְׂרָאֵל הוּקְמָה בִּשְׁנַת 1948",
    # "₪",
    # "מָחָר בְּשָׁעָה 22:00",  # time to word
    # "אוֹרוֹת ווֹלְטֶר ווֹלֶנְטַיְן אֻרְווֹת אוֹרְחִים אָרְבוּ הוֹוֶה וּוּבְּרִים וָו וִי וּוִיקְטוֹר",  # Vavs
    # "לְמַיִם אֱלֹהֵי",
    # "שְׁמַע אָח שֶׁלִּי, תִּרְאֶה. נִרְאֶה לִי שֶׁזֶּה עוֹבֵד!",
    # "גִ'ירָפָה",
    # "יִהְיֶה",
    # "בְּמָה",
    # "בְּיִשְׂרָאֵל.",
    # "אֲוִויר",
    # "לַכִּיווּן",
    # """קִיוּוּ""",
    # "אֻרְווֹת",
    # "וּוִיקְטוֹר",
    # "אֲוִויר",
    # "מְאוּוְרֶרֶת",
    # "טוֹוִים",
    # "מִגְוַון",
    # "הַקַּווְקָז",
    # "בְּסִיוֹוֹן",
    # "צוֹוַחַת",
    # "צוֹוְחִים",
    # "וּוֶנְדֶּר",
    # "וּוַעֲדַת",
    # "שָׁלוֹם",
    # "וּמֶה",
    # "הַתְּרוּמָה",
    # "English",
    # "בַּרִ֫יא",
    # "זֶ֫ה הָיָ֫ה קוֹרֵ֫עַ מִצְּח֫וֹק הֵ֫ם קוֹרְעִ֫ם אוֹתִ֫י"
    # "וּבֽתוֹלְד֫וֹת",
    # "וִירוּשָׁלַיִם",
    # "וְאַתָּה",
    # "אוּרִי",
    # "אַוָּרִי",
    # "וָואלָה",
    # "ווֹלְטֶר",
    # "אוֹרִי",
    # "אֻרִי",
    # "גִּ׳ירָהּ",
    # "גִּ'רַ֫פָה",
    # "זָ'קֵ֫ט",
    # "תַּ'מְבִין",
    # "כֹּחַ",
    # "מֹחַ",
    # "כָּל",
    # "רֵיחַ",
    # "אֶלֶף עֶרֶב",
    # "לִוְיָתָ֫ן",
    # "יִשָּׂשכָר",
    # "יִשָּׂשכָ֫ר",
    # "יַאלְלָה",
    # "אִיָּ֫ר",
    # "אֶנְצִיקְלוֹפֶּ֫דְיָה",
    # "קוֹרֶה"
    # "אָח",
    # "שְׁמוּרִים"
    # "עֶ֫רֶב",
    # "מַגְנִיבָה",
    # "אוֹפַנַּיִים",
    # "אֵיתָנוּת",
    # "רֵיחַ",
    # "אֵיתָנוּת",
    # "אֵיר֫וֹפָּה",
    "צָהֳרַ֫יִם",
    "דַּוָָר",
    "עַכְשָׁ֫יו"
]


for sentence in sentences:
    phonemes = phonemize(
        sentence, 
        preserve_punctuation=True, 
        use_post_normalize=True, 
        use_expander=False,
        predict_stress=True
    )
    print(phonemes)
